# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/checked.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1alpha1/checked.proto',
  package='google.api.expr.v1alpha1',
  syntax='proto3',
  serialized_options=b'\n\034com.google.api.expr.v1alpha1B\tDeclProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&google/api/expr/v1alpha1/checked.proto\x12\x18google.api.expr.v1alpha1\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xb6\x03\n\x0b\x43heckedExpr\x12N\n\rreference_map\x18\x02 \x03(\x0b\x32\x37.google.api.expr.v1alpha1.CheckedExpr.ReferenceMapEntry\x12\x44\n\x08type_map\x18\x03 \x03(\x0b\x32\x32.google.api.expr.v1alpha1.CheckedExpr.TypeMapEntry\x12\x39\n\x0bsource_info\x18\x05 \x01(\x0b\x32$.google.api.expr.v1alpha1.SourceInfo\x12,\n\x04\x65xpr\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Expr\x1aX\n\x11ReferenceMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.google.api.expr.v1alpha1.Reference:\x02\x38\x01\x1aN\n\x0cTypeMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type:\x02\x38\x01\"\x82\n\n\x04Type\x12%\n\x03\x64yn\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12*\n\x04null\x18\x02 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x41\n\tprimitive\x18\x03 \x01(\x0e\x32,.google.api.expr.v1alpha1.Type.PrimitiveTypeH\x00\x12?\n\x07wrapper\x18\x04 \x01(\x0e\x32,.google.api.expr.v1alpha1.Type.PrimitiveTypeH\x00\x12\x42\n\nwell_known\x18\x05 \x01(\x0e\x32,.google.api.expr.v1alpha1.Type.WellKnownTypeH\x00\x12<\n\tlist_type\x18\x06 \x01(\x0b\x32\'.google.api.expr.v1alpha1.Type.ListTypeH\x00\x12:\n\x08map_type\x18\x07 \x01(\x0b\x32&.google.api.expr.v1alpha1.Type.MapTypeH\x00\x12?\n\x08\x66unction\x18\x08 \x01(\x0b\x32+.google.api.expr.v1alpha1.Type.FunctionTypeH\x00\x12\x16\n\x0cmessage_type\x18\t \x01(\tH\x00\x12\x14\n\ntype_param\x18\n \x01(\tH\x00\x12.\n\x04type\x18\x0b \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.TypeH\x00\x12\'\n\x05\x65rror\x18\x0c \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x44\n\rabstract_type\x18\x0e \x01(\x0b\x32+.google.api.expr.v1alpha1.Type.AbstractTypeH\x00\x1a=\n\x08ListType\x12\x31\n\telem_type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x1ao\n\x07MapType\x12\x30\n\x08key_type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x12\x32\n\nvalue_type\x18\x02 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x1av\n\x0c\x46unctionType\x12\x33\n\x0bresult_type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x12\x31\n\targ_types\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x1aU\n\x0c\x41\x62stractType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\x0fparameter_types\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\"s\n\rPrimitiveType\x12\x1e\n\x1aPRIMITIVE_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\t\n\x05INT64\x10\x02\x12\n\n\x06UINT64\x10\x03\x12\n\n\x06\x44OUBLE\x10\x04\x12\n\n\x06STRING\x10\x05\x12\t\n\x05\x42YTES\x10\x06\"V\n\rWellKnownType\x12\x1f\n\x1bWELL_KNOWN_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\r\n\tTIMESTAMP\x10\x02\x12\x0c\n\x08\x44URATION\x10\x03\x42\x0b\n\ttype_kind\"\xb9\x04\n\x04\x44\x65\x63l\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x39\n\x05ident\x18\x02 \x01(\x0b\x32(.google.api.expr.v1alpha1.Decl.IdentDeclH\x00\x12?\n\x08\x66unction\x18\x03 \x01(\x0b\x32+.google.api.expr.v1alpha1.Decl.FunctionDeclH\x00\x1ay\n\tIdentDecl\x12,\n\x04type\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".google.api.expr.v1alpha1.Constant\x12\x0b\n\x03\x64oc\x18\x03 \x01(\t\x1a\x9e\x02\n\x0c\x46unctionDecl\x12G\n\toverloads\x18\x01 \x03(\x0b\x32\x34.google.api.expr.v1alpha1.Decl.FunctionDecl.Overload\x1a\xc4\x01\n\x08Overload\x12\x13\n\x0boverload_id\x18\x01 \x01(\t\x12.\n\x06params\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x12\x13\n\x0btype_params\x18\x03 \x03(\t\x12\x33\n\x0bresult_type\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.Type\x12\x1c\n\x14is_instance_function\x18\x05 \x01(\x08\x12\x0b\n\x03\x64oc\x18\x06 \x01(\tB\x0b\n\tdecl_kind\"a\n\tReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0boverload_id\x18\x03 \x03(\t\x12\x31\n\x05value\x18\x04 \x01(\x0b\x32\".google.api.expr.v1alpha1.ConstantBl\n\x1c\x63om.google.api.expr.v1alpha1B\tDeclProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])



_TYPE_PRIMITIVETYPE = _descriptor.EnumDescriptor(
  name='PrimitiveType',
  full_name='google.api.expr.v1alpha1.Type.PrimitiveType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT64', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UINT64', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BYTES', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1674,
  serialized_end=1789,
)
_sym_db.RegisterEnumDescriptor(_TYPE_PRIMITIVETYPE)

_TYPE_WELLKNOWNTYPE = _descriptor.EnumDescriptor(
  name='WellKnownType',
  full_name='google.api.expr.v1alpha1.Type.WellKnownType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WELL_KNOWN_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMESTAMP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DURATION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1791,
  serialized_end=1877,
)
_sym_db.RegisterEnumDescriptor(_TYPE_WELLKNOWNTYPE)


_CHECKEDEXPR_REFERENCEMAPENTRY = _descriptor.Descriptor(
  name='ReferenceMapEntry',
  full_name='google.api.expr.v1alpha1.CheckedExpr.ReferenceMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.expr.v1alpha1.CheckedExpr.ReferenceMapEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1alpha1.CheckedExpr.ReferenceMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=437,
  serialized_end=525,
)

_CHECKEDEXPR_TYPEMAPENTRY = _descriptor.Descriptor(
  name='TypeMapEntry',
  full_name='google.api.expr.v1alpha1.CheckedExpr.TypeMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.expr.v1alpha1.CheckedExpr.TypeMapEntry.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1alpha1.CheckedExpr.TypeMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=605,
)

_CHECKEDEXPR = _descriptor.Descriptor(
  name='CheckedExpr',
  full_name='google.api.expr.v1alpha1.CheckedExpr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference_map', full_name='google.api.expr.v1alpha1.CheckedExpr.reference_map', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_map', full_name='google.api.expr.v1alpha1.CheckedExpr.type_map', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_info', full_name='google.api.expr.v1alpha1.CheckedExpr.source_info', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expr', full_name='google.api.expr.v1alpha1.CheckedExpr.expr', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHECKEDEXPR_REFERENCEMAPENTRY, _CHECKEDEXPR_TYPEMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=605,
)


_TYPE_LISTTYPE = _descriptor.Descriptor(
  name='ListType',
  full_name='google.api.expr.v1alpha1.Type.ListType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elem_type', full_name='google.api.expr.v1alpha1.Type.ListType.elem_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1291,
  serialized_end=1352,
)

_TYPE_MAPTYPE = _descriptor.Descriptor(
  name='MapType',
  full_name='google.api.expr.v1alpha1.Type.MapType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_type', full_name='google.api.expr.v1alpha1.Type.MapType.key_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_type', full_name='google.api.expr.v1alpha1.Type.MapType.value_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1354,
  serialized_end=1465,
)

_TYPE_FUNCTIONTYPE = _descriptor.Descriptor(
  name='FunctionType',
  full_name='google.api.expr.v1alpha1.Type.FunctionType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_type', full_name='google.api.expr.v1alpha1.Type.FunctionType.result_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arg_types', full_name='google.api.expr.v1alpha1.Type.FunctionType.arg_types', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1585,
)

_TYPE_ABSTRACTTYPE = _descriptor.Descriptor(
  name='AbstractType',
  full_name='google.api.expr.v1alpha1.Type.AbstractType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.expr.v1alpha1.Type.AbstractType.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameter_types', full_name='google.api.expr.v1alpha1.Type.AbstractType.parameter_types', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1587,
  serialized_end=1672,
)

_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='google.api.expr.v1alpha1.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dyn', full_name='google.api.expr.v1alpha1.Type.dyn', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null', full_name='google.api.expr.v1alpha1.Type.null', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primitive', full_name='google.api.expr.v1alpha1.Type.primitive', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wrapper', full_name='google.api.expr.v1alpha1.Type.wrapper', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='well_known', full_name='google.api.expr.v1alpha1.Type.well_known', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_type', full_name='google.api.expr.v1alpha1.Type.list_type', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_type', full_name='google.api.expr.v1alpha1.Type.map_type', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='google.api.expr.v1alpha1.Type.function', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='google.api.expr.v1alpha1.Type.message_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_param', full_name='google.api.expr.v1alpha1.Type.type_param', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.api.expr.v1alpha1.Type.type', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='google.api.expr.v1alpha1.Type.error', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abstract_type', full_name='google.api.expr.v1alpha1.Type.abstract_type', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TYPE_LISTTYPE, _TYPE_MAPTYPE, _TYPE_FUNCTIONTYPE, _TYPE_ABSTRACTTYPE, ],
  enum_types=[
    _TYPE_PRIMITIVETYPE,
    _TYPE_WELLKNOWNTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type_kind', full_name='google.api.expr.v1alpha1.Type.type_kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=608,
  serialized_end=1890,
)


_DECL_IDENTDECL = _descriptor.Descriptor(
  name='IdentDecl',
  full_name='google.api.expr.v1alpha1.Decl.IdentDecl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.api.expr.v1alpha1.Decl.IdentDecl.type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1alpha1.Decl.IdentDecl.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doc', full_name='google.api.expr.v1alpha1.Decl.IdentDecl.doc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2039,
  serialized_end=2160,
)

_DECL_FUNCTIONDECL_OVERLOAD = _descriptor.Descriptor(
  name='Overload',
  full_name='google.api.expr.v1alpha1.Decl.FunctionDecl.Overload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overload_id', full_name='google.api.expr.v1alpha1.Decl.FunctionDecl.Overload.overload_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='google.api.expr.v1alpha1.Decl.FunctionDecl.Overload.params', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_params', full_name='google.api.expr.v1alpha1.Decl.FunctionDecl.Overload.type_params', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_type', full_name='google.api.expr.v1alpha1.Decl.FunctionDecl.Overload.result_type', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_instance_function', full_name='google.api.expr.v1alpha1.Decl.FunctionDecl.Overload.is_instance_function', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doc', full_name='google.api.expr.v1alpha1.Decl.FunctionDecl.Overload.doc', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2253,
  serialized_end=2449,
)

_DECL_FUNCTIONDECL = _descriptor.Descriptor(
  name='FunctionDecl',
  full_name='google.api.expr.v1alpha1.Decl.FunctionDecl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overloads', full_name='google.api.expr.v1alpha1.Decl.FunctionDecl.overloads', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DECL_FUNCTIONDECL_OVERLOAD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2163,
  serialized_end=2449,
)

_DECL = _descriptor.Descriptor(
  name='Decl',
  full_name='google.api.expr.v1alpha1.Decl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.expr.v1alpha1.Decl.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ident', full_name='google.api.expr.v1alpha1.Decl.ident', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='google.api.expr.v1alpha1.Decl.function', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DECL_IDENTDECL, _DECL_FUNCTIONDECL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='decl_kind', full_name='google.api.expr.v1alpha1.Decl.decl_kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1893,
  serialized_end=2462,
)


_REFERENCE = _descriptor.Descriptor(
  name='Reference',
  full_name='google.api.expr.v1alpha1.Reference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.expr.v1alpha1.Reference.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overload_id', full_name='google.api.expr.v1alpha1.Reference.overload_id', index=1,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1alpha1.Reference.value', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2464,
  serialized_end=2561,
)

_CHECKEDEXPR_REFERENCEMAPENTRY.fields_by_name['value'].message_type = _REFERENCE
_CHECKEDEXPR_REFERENCEMAPENTRY.containing_type = _CHECKEDEXPR
_CHECKEDEXPR_TYPEMAPENTRY.fields_by_name['value'].message_type = _TYPE
_CHECKEDEXPR_TYPEMAPENTRY.containing_type = _CHECKEDEXPR
_CHECKEDEXPR.fields_by_name['reference_map'].message_type = _CHECKEDEXPR_REFERENCEMAPENTRY
_CHECKEDEXPR.fields_by_name['type_map'].message_type = _CHECKEDEXPR_TYPEMAPENTRY
_CHECKEDEXPR.fields_by_name['source_info'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._SOURCEINFO
_CHECKEDEXPR.fields_by_name['expr'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._EXPR
_TYPE_LISTTYPE.fields_by_name['elem_type'].message_type = _TYPE
_TYPE_LISTTYPE.containing_type = _TYPE
_TYPE_MAPTYPE.fields_by_name['key_type'].message_type = _TYPE
_TYPE_MAPTYPE.fields_by_name['value_type'].message_type = _TYPE
_TYPE_MAPTYPE.containing_type = _TYPE
_TYPE_FUNCTIONTYPE.fields_by_name['result_type'].message_type = _TYPE
_TYPE_FUNCTIONTYPE.fields_by_name['arg_types'].message_type = _TYPE
_TYPE_FUNCTIONTYPE.containing_type = _TYPE
_TYPE_ABSTRACTTYPE.fields_by_name['parameter_types'].message_type = _TYPE
_TYPE_ABSTRACTTYPE.containing_type = _TYPE
_TYPE.fields_by_name['dyn'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TYPE.fields_by_name['null'].enum_type = google_dot_protobuf_dot_struct__pb2._NULLVALUE
_TYPE.fields_by_name['primitive'].enum_type = _TYPE_PRIMITIVETYPE
_TYPE.fields_by_name['wrapper'].enum_type = _TYPE_PRIMITIVETYPE
_TYPE.fields_by_name['well_known'].enum_type = _TYPE_WELLKNOWNTYPE
_TYPE.fields_by_name['list_type'].message_type = _TYPE_LISTTYPE
_TYPE.fields_by_name['map_type'].message_type = _TYPE_MAPTYPE
_TYPE.fields_by_name['function'].message_type = _TYPE_FUNCTIONTYPE
_TYPE.fields_by_name['type'].message_type = _TYPE
_TYPE.fields_by_name['error'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_TYPE.fields_by_name['abstract_type'].message_type = _TYPE_ABSTRACTTYPE
_TYPE_PRIMITIVETYPE.containing_type = _TYPE
_TYPE_WELLKNOWNTYPE.containing_type = _TYPE
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['dyn'])
_TYPE.fields_by_name['dyn'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['null'])
_TYPE.fields_by_name['null'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['primitive'])
_TYPE.fields_by_name['primitive'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['wrapper'])
_TYPE.fields_by_name['wrapper'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['well_known'])
_TYPE.fields_by_name['well_known'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['list_type'])
_TYPE.fields_by_name['list_type'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['map_type'])
_TYPE.fields_by_name['map_type'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['function'])
_TYPE.fields_by_name['function'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['message_type'])
_TYPE.fields_by_name['message_type'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['type_param'])
_TYPE.fields_by_name['type_param'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['type'])
_TYPE.fields_by_name['type'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['error'])
_TYPE.fields_by_name['error'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_TYPE.oneofs_by_name['type_kind'].fields.append(
  _TYPE.fields_by_name['abstract_type'])
_TYPE.fields_by_name['abstract_type'].containing_oneof = _TYPE.oneofs_by_name['type_kind']
_DECL_IDENTDECL.fields_by_name['type'].message_type = _TYPE
_DECL_IDENTDECL.fields_by_name['value'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._CONSTANT
_DECL_IDENTDECL.containing_type = _DECL
_DECL_FUNCTIONDECL_OVERLOAD.fields_by_name['params'].message_type = _TYPE
_DECL_FUNCTIONDECL_OVERLOAD.fields_by_name['result_type'].message_type = _TYPE
_DECL_FUNCTIONDECL_OVERLOAD.containing_type = _DECL_FUNCTIONDECL
_DECL_FUNCTIONDECL.fields_by_name['overloads'].message_type = _DECL_FUNCTIONDECL_OVERLOAD
_DECL_FUNCTIONDECL.containing_type = _DECL
_DECL.fields_by_name['ident'].message_type = _DECL_IDENTDECL
_DECL.fields_by_name['function'].message_type = _DECL_FUNCTIONDECL
_DECL.oneofs_by_name['decl_kind'].fields.append(
  _DECL.fields_by_name['ident'])
_DECL.fields_by_name['ident'].containing_oneof = _DECL.oneofs_by_name['decl_kind']
_DECL.oneofs_by_name['decl_kind'].fields.append(
  _DECL.fields_by_name['function'])
_DECL.fields_by_name['function'].containing_oneof = _DECL.oneofs_by_name['decl_kind']
_REFERENCE.fields_by_name['value'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._CONSTANT
DESCRIPTOR.message_types_by_name['CheckedExpr'] = _CHECKEDEXPR
DESCRIPTOR.message_types_by_name['Type'] = _TYPE
DESCRIPTOR.message_types_by_name['Decl'] = _DECL
DESCRIPTOR.message_types_by_name['Reference'] = _REFERENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CheckedExpr = _reflection.GeneratedProtocolMessageType('CheckedExpr', (_message.Message,), {

  'ReferenceMapEntry' : _reflection.GeneratedProtocolMessageType('ReferenceMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHECKEDEXPR_REFERENCEMAPENTRY,
    '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.CheckedExpr.ReferenceMapEntry)
    })
  ,

  'TypeMapEntry' : _reflection.GeneratedProtocolMessageType('TypeMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHECKEDEXPR_TYPEMAPENTRY,
    '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.CheckedExpr.TypeMapEntry)
    })
  ,
  'DESCRIPTOR' : _CHECKEDEXPR,
  '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.CheckedExpr)
  })
_sym_db.RegisterMessage(CheckedExpr)
_sym_db.RegisterMessage(CheckedExpr.ReferenceMapEntry)
_sym_db.RegisterMessage(CheckedExpr.TypeMapEntry)

Type = _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {

  'ListType' : _reflection.GeneratedProtocolMessageType('ListType', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_LISTTYPE,
    '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Type.ListType)
    })
  ,

  'MapType' : _reflection.GeneratedProtocolMessageType('MapType', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_MAPTYPE,
    '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Type.MapType)
    })
  ,

  'FunctionType' : _reflection.GeneratedProtocolMessageType('FunctionType', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_FUNCTIONTYPE,
    '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Type.FunctionType)
    })
  ,

  'AbstractType' : _reflection.GeneratedProtocolMessageType('AbstractType', (_message.Message,), {
    'DESCRIPTOR' : _TYPE_ABSTRACTTYPE,
    '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Type.AbstractType)
    })
  ,
  'DESCRIPTOR' : _TYPE,
  '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Type)
  })
_sym_db.RegisterMessage(Type)
_sym_db.RegisterMessage(Type.ListType)
_sym_db.RegisterMessage(Type.MapType)
_sym_db.RegisterMessage(Type.FunctionType)
_sym_db.RegisterMessage(Type.AbstractType)

Decl = _reflection.GeneratedProtocolMessageType('Decl', (_message.Message,), {

  'IdentDecl' : _reflection.GeneratedProtocolMessageType('IdentDecl', (_message.Message,), {
    'DESCRIPTOR' : _DECL_IDENTDECL,
    '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Decl.IdentDecl)
    })
  ,

  'FunctionDecl' : _reflection.GeneratedProtocolMessageType('FunctionDecl', (_message.Message,), {

    'Overload' : _reflection.GeneratedProtocolMessageType('Overload', (_message.Message,), {
      'DESCRIPTOR' : _DECL_FUNCTIONDECL_OVERLOAD,
      '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
      # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Decl.FunctionDecl.Overload)
      })
    ,
    'DESCRIPTOR' : _DECL_FUNCTIONDECL,
    '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Decl.FunctionDecl)
    })
  ,
  'DESCRIPTOR' : _DECL,
  '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Decl)
  })
_sym_db.RegisterMessage(Decl)
_sym_db.RegisterMessage(Decl.IdentDecl)
_sym_db.RegisterMessage(Decl.FunctionDecl)
_sym_db.RegisterMessage(Decl.FunctionDecl.Overload)

Reference = _reflection.GeneratedProtocolMessageType('Reference', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCE,
  '__module__' : 'google.api.expr.v1alpha1.checked_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.Reference)
  })
_sym_db.RegisterMessage(Reference)


DESCRIPTOR._options = None
_CHECKEDEXPR_REFERENCEMAPENTRY._options = None
_CHECKEDEXPR_TYPEMAPENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/listener/udp_listener_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/listener/udp_listener_config.proto',
  package='envoy.api.v2.listener',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.api.v2.listenerB\026UdpListenerConfigProtoP\001\252\002\027Envoy.Api.V2.ListenerNS\352\002\027Envoy.Api.V2.ListenerNS\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/envoy/api/v2/listener/udp_listener_config.proto\x12\x15\x65nvoy.api.v2.listener\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x9a\x01\n\x11UdpListenerConfig\x12\x19\n\x11udp_listener_name\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\"\x1c\n\x1a\x41\x63tiveRawUdpListenerConfigB\x9b\x01\n#io.envoyproxy.envoy.api.v2.listenerB\x16UdpListenerConfigProtoP\x01\xaa\x02\x17\x45nvoy.Api.V2.ListenerNS\xea\x02\x17\x45nvoy.Api.V2.ListenerNS\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_UDPLISTENERCONFIG = _descriptor.Descriptor(
  name='UdpListenerConfig',
  full_name='envoy.api.v2.listener.UdpListenerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='udp_listener_name', full_name='envoy.api.v2.listener.UdpListenerConfig.udp_listener_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.api.v2.listener.UdpListenerConfig.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.api.v2.listener.UdpListenerConfig.typed_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.api.v2.listener.UdpListenerConfig.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=195,
  serialized_end=349,
)


_ACTIVERAWUDPLISTENERCONFIG = _descriptor.Descriptor(
  name='ActiveRawUdpListenerConfig',
  full_name='envoy.api.v2.listener.ActiveRawUdpListenerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=379,
)

_UDPLISTENERCONFIG.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UDPLISTENERCONFIG.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_UDPLISTENERCONFIG.oneofs_by_name['config_type'].fields.append(
  _UDPLISTENERCONFIG.fields_by_name['config'])
_UDPLISTENERCONFIG.fields_by_name['config'].containing_oneof = _UDPLISTENERCONFIG.oneofs_by_name['config_type']
_UDPLISTENERCONFIG.oneofs_by_name['config_type'].fields.append(
  _UDPLISTENERCONFIG.fields_by_name['typed_config'])
_UDPLISTENERCONFIG.fields_by_name['typed_config'].containing_oneof = _UDPLISTENERCONFIG.oneofs_by_name['config_type']
DESCRIPTOR.message_types_by_name['UdpListenerConfig'] = _UDPLISTENERCONFIG
DESCRIPTOR.message_types_by_name['ActiveRawUdpListenerConfig'] = _ACTIVERAWUDPLISTENERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UdpListenerConfig = _reflection.GeneratedProtocolMessageType('UdpListenerConfig', (_message.Message,), {
  'DESCRIPTOR' : _UDPLISTENERCONFIG,
  '__module__' : 'envoy.api.v2.listener.udp_listener_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.listener.UdpListenerConfig)
  })
_sym_db.RegisterMessage(UdpListenerConfig)

ActiveRawUdpListenerConfig = _reflection.GeneratedProtocolMessageType('ActiveRawUdpListenerConfig', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVERAWUDPLISTENERCONFIG,
  '__module__' : 'envoy.api.v2.listener.udp_listener_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.listener.ActiveRawUdpListenerConfig)
  })
_sym_db.RegisterMessage(ActiveRawUdpListenerConfig)


DESCRIPTOR._options = None
_UDPLISTENERCONFIG.fields_by_name['config']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/tap/v3/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.tap.v3 import common_pb2 as envoy_dot_config_dot_tap_dot_v3_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/common/tap/v3/common.proto',
  package='envoy.extensions.common.tap.v3',
  syntax='proto3',
  serialized_options=b'\n,io.envoyproxy.envoy.extensions.common.tap.v3B\013CommonProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+envoy/extensions/common/tap/v3/common.proto\x12\x1e\x65nvoy.extensions.common.tap.v3\x1a envoy/config/tap/v3/common.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe7\x01\n\x15\x43ommonExtensionConfig\x12\x43\n\x0c\x61\x64min_config\x18\x01 \x01(\x0b\x32+.envoy.extensions.common.tap.v3.AdminConfigH\x00\x12\x37\n\rstatic_config\x18\x02 \x01(\x0b\x32\x1e.envoy.config.tap.v3.TapConfigH\x00:<\x9a\xc5\x88\x1e\x37\n5envoy.config.common.tap.v2alpha.CommonExtensionConfigB\x12\n\x0b\x63onfig_type\x12\x03\xf8\x42\x01\"]\n\x0b\x41\x64minConfig\x12\x1a\n\tconfig_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:2\x9a\xc5\x88\x1e-\n+envoy.config.common.tap.v2alpha.AdminConfigBE\n,io.envoyproxy.envoy.extensions.common.tap.v3B\x0b\x43ommonProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_tap_dot_v3_dot_common__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_COMMONEXTENSIONCONFIG = _descriptor.Descriptor(
  name='CommonExtensionConfig',
  full_name='envoy.extensions.common.tap.v3.CommonExtensionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='admin_config', full_name='envoy.extensions.common.tap.v3.CommonExtensionConfig.admin_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_config', full_name='envoy.extensions.common.tap.v3.CommonExtensionConfig.static_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0367\n5envoy.config.common.tap.v2alpha.CommonExtensionConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.extensions.common.tap.v3.CommonExtensionConfig.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=205,
  serialized_end=436,
)


_ADMINCONFIG = _descriptor.Descriptor(
  name='AdminConfig',
  full_name='envoy.extensions.common.tap.v3.AdminConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_id', full_name='envoy.extensions.common.tap.v3.AdminConfig.config_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.config.common.tap.v2alpha.AdminConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=531,
)

_COMMONEXTENSIONCONFIG.fields_by_name['admin_config'].message_type = _ADMINCONFIG
_COMMONEXTENSIONCONFIG.fields_by_name['static_config'].message_type = envoy_dot_config_dot_tap_dot_v3_dot_common__pb2._TAPCONFIG
_COMMONEXTENSIONCONFIG.oneofs_by_name['config_type'].fields.append(
  _COMMONEXTENSIONCONFIG.fields_by_name['admin_config'])
_COMMONEXTENSIONCONFIG.fields_by_name['admin_config'].containing_oneof = _COMMONEXTENSIONCONFIG.oneofs_by_name['config_type']
_COMMONEXTENSIONCONFIG.oneofs_by_name['config_type'].fields.append(
  _COMMONEXTENSIONCONFIG.fields_by_name['static_config'])
_COMMONEXTENSIONCONFIG.fields_by_name['static_config'].containing_oneof = _COMMONEXTENSIONCONFIG.oneofs_by_name['config_type']
DESCRIPTOR.message_types_by_name['CommonExtensionConfig'] = _COMMONEXTENSIONCONFIG
DESCRIPTOR.message_types_by_name['AdminConfig'] = _ADMINCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CommonExtensionConfig = _reflection.GeneratedProtocolMessageType('CommonExtensionConfig', (_message.Message,), {
  'DESCRIPTOR' : _COMMONEXTENSIONCONFIG,
  '__module__' : 'envoy.extensions.common.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.common.tap.v3.CommonExtensionConfig)
  })
_sym_db.RegisterMessage(CommonExtensionConfig)

AdminConfig = _reflection.GeneratedProtocolMessageType('AdminConfig', (_message.Message,), {
  'DESCRIPTOR' : _ADMINCONFIG,
  '__module__' : 'envoy.extensions.common.tap.v3.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.common.tap.v3.AdminConfig)
  })
_sym_db.RegisterMessage(AdminConfig)


DESCRIPTOR._options = None
_COMMONEXTENSIONCONFIG.oneofs_by_name['config_type']._options = None
_COMMONEXTENSIONCONFIG._options = None
_ADMINCONFIG.fields_by_name['config_id']._options = None
_ADMINCONFIG._options = None
# @@protoc_insertion_point(module_scope)
